Module mock

Module mock 

Mock table system for generating test data as SELECT ... UNION ALL SELECT ....

When the composer encounters a table name that has a mock registered, it can substitute a generated SELECT statement that produces the mock data.

Structs

MockTable
A mock table definition with column data for test substitution.