pub fn template<'i, Input, Error>(
input: &mut Input,
) -> Result<Vec<Element>, Error>Expand description
Parse a complete template into a sequence of elements.
This is the top-level parser entry point for template content.
pub fn template<'i, Input, Error>(
input: &mut Input,
) -> Result<Vec<Element>, Error>Parse a complete template into a sequence of elements.
This is the top-level parser entry point for template content.