pub enum Error {
TemplateNotFound {
path: PathBuf,
},
Parse {
location: String,
message: String,
},
MissingBinding {
name: String,
},
ComposeNotFound {
path: PathBuf,
},
CommandSourceNotFound {
path: PathBuf,
},
Io(Error),
MockNotFound {
name: String,
},
CircularReference {
path: PathBuf,
},
MissingSlot {
name: String,
},
}Expand description
The error type for sql-composer operations.
Variants
TemplateNotFound
A referenced template file was not found on any search path.
Parse
A parse error occurred while processing a template.
Fields
MissingBinding
A binding referenced in the template was not provided values.
ComposeNotFound
A compose reference could not be resolved.
CommandSourceNotFound
A command references sources that could not be resolved.
Io(Error)
An I/O error occurred while reading a template file.
MockNotFound
A mock table was referenced but not registered.
CircularReference
A circular compose reference was detected.
MissingSlot
A slot referenced in a template was not provided by the caller.