winnow 0.7 parsers for sql-composer template macros.
The parser treats SQL text as opaque literals and only recognizes the
template macro syntax: :bind(...), :compose(...), :count(...),
and :union(...).
Modules
- bind
- Parser for
:bind(name [EXPECTING min[..max]] [NULL])macros. - command
- Parser for
:count(...)and:union(...)command macros. - compose
- Parser for
:compose(path)macros. - template
- Top-level template parser that dispatches between macros and literal SQL.
Functions
- parse_
template - Parse a template string into a
Template. - parse_
template_ file - Parse a template from a file path.